-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA1

Hi, the attached diff would fix the wrong CVS references in
exchange.e.org
I'm not able to check it on my laptop 'cause my copy of exchange isn't
fully working (i'm checking for errors).
To fix all of the problem reported by Nicolas Aguirre, we also have to
fix the source URL for each object in exchange's db that refers to a
source tree.

My two cents

Massimiliano
- -- 
Massimiliano Calamelli
http://mcalamelli.netsons.org
[EMAIL PROTECTED]
-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.4.7 (MingW32)

iD8DBQFI0PBYleGEL56NNP4RAp9IAKDMUigh4kxkQ9l9a63pPlVbsWIcjwCghNAz
r3yZTl3fC+PBega1hP9mbA8=
=S7Sp
-----END PGP SIGNATURE-----
Index: apps/exchange/modules/home/templates/cvsSuccess.php
===================================================================
--- apps/exchange/modules/home/templates/cvsSuccess.php (revisione 36010)
+++ apps/exchange/modules/home/templates/cvsSuccess.php (copia locale)
@@ -1,6 +1,6 @@
-<?php slot('title') ?>Download from official Enlightenment CVS<?php end_slot() 
?>
-<h1>Download from official Enlightenment CVS</h1>
-This code is available from the Enlightenment CVS at: <strong><?php echo $path 
?></strong><br/>
+<?php slot('title') ?>Download from official Enlightenment SVN<?php end_slot() 
?>
+<h1>Download from official Enlightenment SVN</h1>
+This code is available from the Enlightenment SVN at: <strong><?php echo $path 
?></strong><br/>
 To download, run the following command:<br/>
-<strong>cvs -z3 -d:pserver:[EMAIL PROTECTED]:/var/cvs/e co <?php echo $path 
?></strong><br/>
-For information on using CVS, please visit the <a 
href="http://wiki.enlightenment.org/index.php/E17_User_Guide/Installing_Using_CVS";>wiki</a>.
\ No newline at end of file
+<strong>svn co http://svn.enlightenment.org/svn/e/trunk<?php echo $path 
?></strong><br/>
+For information on using SVN, please visit the <a 
href="http://wiki.enlightenment.org/index.php/E17_User_Guide/Installing_from_Source_Repository";>wiki</a>.
\ No newline at end of file
Index: config/config_prod.php
===================================================================
--- config/config_prod.php      (revisione 36011)
+++ config/config_prod.php      (copia locale)
@@ -2,4 +2,6 @@
 
 // symfony directories
 $sf_symfony_lib_dir  = '/var/www/exchange/symfony/lib';
+//$sf_symfony_lib_dir  = '/usr/share/php/symfony';
 $sf_symfony_data_dir = '/var/www/exchange/symfony/data';
+//$sf_symfony_data_dir = '/usr/share/php/data/symfony/data';
Index: config/ProjectConfiguration.class.php
===================================================================
--- config/ProjectConfiguration.class.php       (revisione 36011)
+++ config/ProjectConfiguration.class.php       (copia locale)
@@ -1,6 +1,6 @@
 <?php
 
-require_once 
dirname(__FILE__).'/../../symfony/lib/autoload/sfCoreAutoload.class.php';
+require_once '/usr/share/php/symfony/autoload/sfCoreAutoload.class.php';
 sfCoreAutoload::register();
 
 class ProjectConfiguration extends sfProjectConfiguration
Index: lib/model/doctrine/Application.class.php
===================================================================
--- lib/model/doctrine/Application.class.php    (revisione 36010)
+++ lib/model/doctrine/Application.class.php    (copia locale)
@@ -52,7 +52,7 @@
                        || stripos($url, 'e_modules')===0
                        || stripos($url, 'eterm')===0
                        || stripos($url, 'misc')===0)
-                       return '/home/cvs/path/'.urlencode(str_replace('/', 
'|', $url));
+                       return '/home/svn/path/'.urlencode(str_replace('/', 
'|', $url));
                return $url;
        }
        
Index: lib/model/doctrine/Madule.class.php
===================================================================
--- lib/model/doctrine/Madule.class.php (revisione 36010)
+++ lib/model/doctrine/Madule.class.php (copia locale)
@@ -52,7 +52,7 @@
                        || stripos($url, 'e_modules')===0
                        || stripos($url, 'eterm')===0
                        || stripos($url, 'misc')===0)
-                       return '/home/cvs/path/'.urlencode(str_replace('/', 
'|', $url));
+                       return '/home/svn/path/'.urlencode(str_replace('/', 
'|', $url));
                return $url;
        }
        
Index: lib/form/ApplicationForm.class.php
===================================================================
--- lib/form/ApplicationForm.class.php  (revisione 36010)
+++ lib/form/ApplicationForm.class.php  (copia locale)
@@ -19,7 +19,7 @@
                ));
                $this->widgetSchema->setHelps(array(
                        'description' => '<a href="/home/wikiSyntax" 
target=_blank>Syntax</a>',
-                       'source_url' => 'If this application is in CVS, just 
enter the path to the CVS module',
+                       'source_url' => 'If this application is in SVN, just 
enter the path to the SVN module',
                ));
                $this->widgetSchema->setNameFormat('application[%s]');
                
Index: lib/form/ModuleForm.class.php
===================================================================
--- lib/form/ModuleForm.class.php       (revisione 36010)
+++ lib/form/ModuleForm.class.php       (copia locale)
@@ -22,7 +22,7 @@
                ));
                $this->widgetSchema->setHelps(array(
                        'description' => '<a href="/home/wikiSyntax" 
target=_blank>Syntax</a>',
-                       'source_url' => 'If this module is in CVS, just enter 
the path to the CVS module',
+                       'source_url' => 'If this module is in SVN, just enter 
the path to the SVN module',
                ));
                $this->widgetSchema->setNameFormat('madule[%s]');
-------------------------------------------------------------------------
This SF.Net email is sponsored by the Moblin Your Move Developer's challenge
Build the coolest Linux based applications with Moblin SDK & win great prizes
Grand prize is a trip for two to an Open Source event anywhere in the world
http://moblin-contest.org/redirect.php?banner_id=100&url=/
_______________________________________________
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel

Reply via email to
Index: apps/exchange/lib/WikiText.class.php
===================================================================
--- apps/exchange/lib/WikiText.class.php        (revisione 36010)
+++ apps/exchange/lib/WikiText.class.php        (copia locale)
@@ -67,7 +67,7 @@
     'tables' => array ('#^\{\|(.*?)(?:^\|\+(.*?))?(^(?:((?R))|.)*?)^\|}#msi', 
'table_callback'),
     'external_links' => array 
("/(\[)?((http\:\/\/|https\:\/\/|ftp\:\/\/|gopher\:\/\/|news\:\/\/)[\w|\d|\.|_|\-]+[A-Za-z0-9\/?=&%~_\-\.\:#;',]*)(?(1)([
 ]+[^\]]+)?\])/i", 'url_callback'),
     'email' => array ('/(\[)?mailto:([\w|\d|\.|_|[EMAIL 
PROTECTED]|\d|\.|_|-]+)(?(1)\])/i', 'email_callback'),
-    'cvs' => array ('/(\[)?cvs:([^\||^\]|^\[]+)(?(1)\])/i', 'cvs_callback'),
+    'svn' => array ('/(\[)?svn:([^\||^\]|^\[]+)(?(1)\])/i', 'cvs_callback'),
     'theme' => array ('/(\[)?theme:([^\]|^\[]+)(?(1)\])/i', 'theme_callback'),
     'module' => array ('/(\[)?module:([^\]|^\[]+)(?(1)\])/i', 
'module_callback'),
     'app' => array ('/(\[)?app:([^\]|^\[]+)(?(1)\])/i', 'app_callback'),
@@ -614,13 +614,13 @@
   
 
   /**
    * The callback function for cvs links
    */     
   private function cvs_callback($matches) {
     $whole = $matches[0];
     $addr = $matches[2];
     $addr2 = urlencode(str_replace('/', '|', $addr));
-    $ret = "<a href=\"/home/cvs/path/{$addr2}\">CVS: $addr</a>";
+    $ret = "<a href=\"/home/svn/path/{$addr2}\">SVN: $addr</a>";
     
     return $ret;
   }
@@ -614,13 +614,13 @@
 
   /**
-   * The callback function for cvs links
+   * The callback function for svn links
    */     
   private function cvs_callback($matches) {